<?php 
add_action('admin_menu', 'pmill_csit_item_menu');
function pmill_csit_item_menu() {
	global $pmill_csit_settings;

	// Options page with script/css loading on demand
	$pmill_csit_settings = add_options_page( PMILL_CSIT_PLUGIN_NAME.' Settings', PMILL_CSIT_PLUGIN_NAME, 'manage_options', 'pmill_csit_config', 'pmill_csit_config');
}

// WP Pointer Admin Tooltip - Make sure you use cookie to dismiss
add_action('admin_enqueue_scripts', 'pmill_csit_enqueue_pointer_scripts');
function pmill_csit_enqueue_pointer_scripts() {
	$dismissed = explode (',', get_user_meta (wp_get_current_user ()->ID, 'dismissed_wp_pointers', true));
    $not_in_array = !in_array ('pmill_csit_settings_dismiss', $dismissed);

    if( $not_in_array ) {
	    wp_enqueue_style('wp-pointer');
	    wp_enqueue_script('wp-pointer');
	    //hook the pointer 
	    add_action('admin_print_footer_scripts', 'pmill_csit_pointer_footer_scripts' );
	}
}
function pmill_csit_pointer_footer_scripts() {
    $pointer_content = '<h3>'.PMILL_CSIT_PLUGIN_NAME.'</h3>';
    $pointer_content .= '<p>Configure your settings here.</p>';
?>
   <script type="text/javascript">
   //<![CDATA[
   jQuery(document).ready( function($) {
    //jQuery selector to point to 
    $('#menu-settings').pointer({
        content: '<?php echo $pointer_content; ?>',
        position: 'top',
        close: function() {
            // This function is fired when you click the close button
            $.post (ajaxurl, {
		        pointer: 'pmill_csit_settings_dismiss',
		        action: 'dismiss-wp-pointer'
		    });
        }
      }).pointer('open');
   });
   //]]>
   </script>
<?php
}

add_action('admin_init', 'pmill_csit_settings_api_init');
function pmill_csit_settings_api_init() {
	//Add sections to add field later
	add_settings_section( 'pmill_csit_buttons', 'Save Buttons', 'pmill_csit_buttons_settings', 'pmill_csit_settings_page' );
	add_settings_section( 'pmill_csit_connectors', 'API Connectors', 'pmill_csit_connectors_settings', 'pmill_csit_settings_page' );
	//add_settings_section( 'pmill_csit_housekeeping', 'Plugin Housekeeping', 'pmill_csit_housekeeping_settings', 'pmill_csit_settings_page' );

	// Buttons
	add_settings_field( 'pmill_csit_rm_gdrive', 'Use Google Drive?', 'pmill_csit_rm_gdrive_callback', 'pmill_csit_settings_page', 'pmill_csit_buttons' );
	add_settings_field( 'pmill_csit_local_label', 'Save To Local Label', 'pmill_csit_local_label_callback', 'pmill_csit_settings_page', 'pmill_csit_buttons' );
	// Connectors
	add_settings_field( 'pmill_csit_dbapi', 'Dropbox key', 'pmill_csit_dbapi_callback', 'pmill_csit_settings_page', 'pmill_csit_connectors' );
	add_settings_field( 'pmill_csit_s3access', 'Amazon S3 Access', 'pmill_csit_s3access_callback', 'pmill_csit_settings_page', 'pmill_csit_connectors' );
	add_settings_field( 'pmill_csit_s3secret', 'Amazon S3 Secret', 'pmill_csit_s3secret_callback', 'pmill_csit_settings_page', 'pmill_csit_connectors' );
	add_settings_field( 'pmill_csit_s3expiry', 'Amazon S3 Expiry', 'pmill_csit_s3expiry_callback', 'pmill_csit_settings_page', 'pmill_csit_connectors' );
	// Housekeeping
	//add_settings_field( 'pmill_csit_del_opt_settings', 'Delete Settings', 'pmill_csit_del_opt_settings_callback', 'pmill_csit_settings_page', 'pmill_csit_housekeeping' );

	//Register our setting
	register_setting( 'pmill_csit_settings_group', 'pmill_csit_options', $sanitize_callback = 'pmill_csit_validate_settings' );
} //End pmill_csit_settings_api_init

// Settings Section Callbacks
function pmill_csit_buttons_settings() {}
function pmill_csit_connectors_settings() {
	?>
	Enter your API keys.
	<?php
}
function pmill_csit_housekeeping_settings() {}

// Settings Field Callbacks
function pmill_csit_local_label_callback() {
	global $pmill_csit_opts;
	$local_label = ( empty($pmill_csit_opts['local_label'] ) ) ? 'Save To Local Drive' : stripslashes($pmill_csit_opts['local_label']) ;
	?>
	<input type="text" id="localLabel" class="localLabel regular-text" name="pmill_csit_options[local_label]" value="<?php echo $local_label; ?>"><br>
	<small>Text label for regular download link</small>
	<?php
}
function pmill_csit_dbapi_callback() {
	global $pmill_csit_opts;
	$dropbox_key = ( empty($pmill_csit_opts['dropbox_key'] ) ) ? '' : stripslashes($pmill_csit_opts['dropbox_key']) ;
	?>
	<input type="password" id="dropboxKey" class="dropboxKey regular-text" name="pmill_csit_options[dropbox_key]" value="<?php echo $dropbox_key; ?>"> <small>Last 3 of key is ...<?php echo substr($dropbox_key, -3); ?></small>
	<br>
	<small>Get Dropbox app key <a href="https://www.dropbox.com/developers/apps/create?app_type_checked=dropins" target="_blank">here</a>. Dropbox account & sign in required.</small>
	<?php
}
function pmill_csit_rm_gdrive_callback() {
	global $pmill_csit_opts;
	$rm_gdrive = ( empty($pmill_csit_opts['rm_gdrive'] ) ) ? '0' : '1' ;
	?>
	<input type="checkbox" id="rm_gdrive" class="rm_gdrive" name="pmill_csit_options[rm_gdrive]" value="1" <?php checked( $rm_gdrive, '1', true ); ?>> <label for="rm_gdrive"><small>No, don't use Save To Google Drive.</small></label>
	<?php
}
function pmill_csit_s3access_callback() {
	global $pmill_csit_opts;
	$s3access = ( empty($pmill_csit_opts['s3access'] ) ) ? '' : stripslashes($pmill_csit_opts['s3access']) ;
	?>
	<input type="password" id="s3Access" class="s3Access regular-text" name="pmill_csit_options[s3access]" value="<?php echo $s3access; ?>"> <small>Last 3 of key is ...<?php echo substr($s3access, -3); ?></small>
	<?php
}
function pmill_csit_s3secret_callback() {
	global $pmill_csit_opts;
	$s3secret = ( empty($pmill_csit_opts['s3secret'] ) ) ? '' : stripslashes($pmill_csit_opts['s3secret']) ;
	?>
	<input type="password" id="s3Secret" class="s3Secret regular-text" name="pmill_csit_options[s3secret]" value="<?php echo $s3secret; ?>"> <small>Last 3 of key is ...<?php echo substr($s3secret, -3); ?></small>
	<?php
}
function pmill_csit_s3expiry_callback() {
	global $pmill_csit_opts;
	$s3expiry = ( empty($pmill_csit_opts['s3expiry'] ) ) ? '' : stripslashes($pmill_csit_opts['s3expiry']) ;
	?>
	<input type="text" id="s3expiry" class="s3expiry small-text" name="pmill_csit_options[s3expiry]" value="<?php echo $s3expiry; ?>">
	<?php
}
function pmill_csit_del_opt_settings_callback() {
	global $pmill_csit_opts;
	$del_opt_settings = ( empty( $pmill_csit_opts['del_opt_settings'] ) ) ? '' : $pmill_csit_opts['del_opt_settings'];
	?>
	<input id="del_opt_settings" type="checkbox" name="pmill_csit_options[del_opt_settings]" value="1" id="del_opt_settings" <?php checked( $del_opt_settings, '1', true ); ?>> <label for="del_opt_settings">Yes. Delete all plugin data when I uninstall</label><br>
	<small>Use with caution! When checked, all of this plugin's settings will be deleted on plugin uninstall. Disabling the plugin will not delete data only uninstall.<br>If re-installing, do not check this box.</small>
	<?php
}
// Validate input
function pmill_csit_validate_settings( $input ) {
	$pmill_csit_opts = get_option( 'pmill_csit_options' );
	$valid_input = $pmill_csit_opts;

	$local_label = ( empty( $input['local_label'] ) ) ? '' : sanitize_text_field( $input['local_label'] );
	$dropbox_key = ( empty( $input['dropbox_key'] ) ) ? '' : sanitize_text_field( $input['dropbox_key'] );
	$s3access = ( empty( $input['s3access'] ) ) ? '' : sanitize_text_field( $input['s3access'] );
	$s3secret = ( empty( $input['s3secret'] ) ) ? '' : sanitize_text_field( $input['s3secret'] );
	$s3expiry = ( !empty( $input['s3expiry'] ) && is_numeric( $input['s3expiry'] ) ) ? sanitize_text_field( $input['s3expiry'] ) : '' ;
	$rm_gdrive = ( empty( $input['rm_gdrive'] ) ) ? '0' : '1' ;
	//$del_opt_settings = ( isset( $input['del_opt_settings'] ) && $input['del_opt_settings'] == '1' ) ? '1' : '0' ;

	// Build array to save
	$valid_input = array(
		'local_label' => $local_label,
		'dropbox_key' => $dropbox_key,
		's3access' => $s3access,
		's3secret' => $s3secret,
		's3expiry' => $s3expiry,
		'rm_gdrive' => $rm_gdrive,
		//'del_opt_settings' => $del_opt_settings
		);
	
	return $valid_input;
}

// Callback for screen output
function pmill_csit_config(){

?>
<div class="wrap">
<h2><?php echo PMILL_CSIT_PLUGIN_NAME; ?> Settings</h2>
<form method="POST" action="options.php">
<?php
	//pass slug name of page, also referred to in Settings API as option group name
	settings_fields( 'pmill_csit_settings_group' );	
	do_settings_sections( 'pmill_csit_settings_page' ); 	//pass slug name of page
	submit_button();
?>
</form>
  
</div>
<?php 
}
?>